perl_cpan_polymake_prereq: Represents all Perl packages that are prerequisites for polymake
===========================================================================================

Description
-----------

This script package represents all Perl packages that are prerequisites
for polymake.

License
-------

Various free software licenses
